function commonSubmitArgs = getCommonSubmitArgs(cluster, numWorkers)
% Get any additional submit arguments for the Slurm sbatch command
% that are common to both independent and communicating jobs.

% Copyright 2016-2019 The MathWorks, Inc.

% wiki: https://crc.pitt.edu/h2p

commonSubmitArgs = '';

% Number of cores/node
ppn = validatedPropValue(cluster, 'ProcsPerNode', 'double');
if ppn>0
    % Don't request more cores/node than workers
    ppn = min(numWorkers,ppn);
    commonSubmitArgs = sprintf('%s --ntasks-per-node=%d',commonSubmitArgs,ppn);
end
commonSubmitArgs = sprintf('%s --ntasks-per-core=1',commonSubmitArgs);

%% REQUIRED 

% Cluster Name
cn = validatedPropValue(cluster, 'ClusterName', 'char');
if ~isempty(cn)
    commonSubmitArgs = [commonSubmitArgs ' --cluster ' cn];
else
    emsg = sprintf(['\n\t>> %% Must set ClusterName.\n', ...
                    '\t>> %% To set ClusterName to ''smp'':\n\n', ...
                    '\t>> c.AdditionalProperties.ClusterName = ''smp'';\n', ...
                    '\t>> c.saveProfile\n\n']);
    error(emsg) %#ok<SPERR>    
end

%% OPTIONAL

% Account Name
an = validatedPropValue(cluster, 'AccountName', 'char');
if ~isempty(an)
    commonSubmitArgs = [commonSubmitArgs ' -A ' an];
end

% Email notification
ea = validatedPropValue(cluster, 'EmailAddress', 'char');
if ~isempty(ea)
    commonSubmitArgs = [commonSubmitArgs ' --mail-type=ALL --mail-user=' ea];
end

% Feature/Constratint
ft = validatedPropValue(cluster, 'Feature', 'char');
if ~isempty(ft)
    commonSubmitArgs = [commonSubmitArgs ' --constraint ' ft];
end

% GPU Selection
ngpus = validatedPropValue(cluster, 'GpusPerNode', 'double');
if ngpus>0 
    commonSubmitArgs = sprintf('%s --gres=gpu:%d', commonSubmitArgs, ngpus);
end

% Physical Memory used by a single core
mu = validatedPropValue(cluster, 'MemUsage', 'char');
if ~isempty(mu)
    commonSubmitArgs = [commonSubmitArgs ' --mem-per-cpu=' mu];
end

% Number of nodes
nn = validatedPropValue(cluster, 'Nodes', 'double');
if nn>0
    commonSubmitArgs = sprintf('%s -N %d', commonSubmitArgs, nn);
end

% Queue Name
qn = validatedPropValue(cluster, 'Partition', 'char');
if ~isempty(qn)
    commonSubmitArgs = [commonSubmitArgs ' -p ' qn];
end

% Reservation 
res = validatedPropValue(cluster, 'Reservation', 'char');
if ~isempty(res)
    commonSubmitArgs = [commonSubmitArgs ' --reservation ' res];
end

% Walltime
wt = validatedPropValue(cluster, 'WallTime', 'char');
if ~isempty(wt)
    commonSubmitArgs = [commonSubmitArgs ' -t ' wt];
end

% Catch-all
asa = validatedPropValue(cluster, 'AdditionalSubmitArgs', 'char');
if ~isempty(asa)
    commonSubmitArgs = [commonSubmitArgs ' ' asa];
end

commonSubmitArgs = strtrim(commonSubmitArgs);
